@@ -112,25 +112,25 @@ class Daisi:
         clean_args = args
 
         # Parse the arguments
-        for argument_name, argument_value in args.items():
+        # for argument_name, argument_value in args.items():
 
-            # If the argument is a daisi output, we must chain the data
-            if type(argument_value) == list:
+        #     # If the argument is a daisi output, we must chain the data
+        #     if type(argument_value) == list:
 
-                # Assume it's the first output
-                try:
-                    clean_args[argument_name] = argument_value[0]["data"]
+        #         # Assume it's the first output
+        #         try:
+        #             clean_args[argument_name] = argument_value[0]["data"]
 
-                    # Check whether the ids of outputs match
-                    for arg in argument_value:
+        #             # Check whether the ids of outputs match
+        #             for arg in argument_value:
 
-                        # If the id of a particular output matches the argument name, set the value
-                        if arg["id"].startswith(argument_name) or argument_name.startswith(
-                            arg["id"]
-                        ):
-                            clean_args[argument_name] = arg["data"]
-                except:
-                    continue
+        #                 # If the id of a particular output matches the argument name, set the value
+        #                 if arg["id"].startswith(argument_name) or argument_name.startswith(
+        #                     arg["id"]
+        #                 ):
+        #                     clean_args[argument_name] = arg["data"]
+        #         except:
+        #             continue
 
         return clean_args
 
